##  Importing and Exporting a Survey
Instead of designing a survey from scratch, to save time and simplify the survey creation, you can import an existing survey from various sources:
  * Import an existing survey from the workspace.
  * Use a survey template from the SAP LeanIX store.
  * Import a previously exported survey in JSON format or directly paste the JSON code during import.


To import a survey, do the following:
  1. Click Use Template in the top right corner of the survey editor. This action opens an overlay with options for importing.
  2. In the overlay, choose whether to import from the workspace, SAP LeanIX store, or a saved survey file.
  3. Click Import.


Similarly, you can export a survey as a JSON file for future use or to use in another workspace, by selecting Export from the menu next to the Use Template button.
![Importing and Exporting Surveys](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2747a0747a44101484cfdee3dc0ae0f1_LowRes.gif)
Importing and Exporting Surveys
